@@ -82,7 +82,7 @@ struct ECA_MINOR_REQUEST_ELEMENT_1
   const char *longname = nullptr;
   const char *units = nullptr;
   ECA_FUNC_1 h1 = nullptr;
-  double h1arg;
+  double h1arg = 0.0;
   ECA_FUNC_2 h2 = nullptr;
   ECA_FUNC_2 h3 = nullptr;
 };
@@ -121,15 +121,15 @@ struct ECA_MAJOR_REQUEST_ELEMENT_2
   const char *name = nullptr;
   const char *longname = nullptr;
   const char *units = nullptr;
-  int refdate;
+  int refdate = 0;
   ECA_FUNC_1 f1 = nullptr;
-  double f1arg;
+  double f1arg = 0.0;
   ECA_FUNC_1 f2 = nullptr;
-  double f2arg;
+  double f2arg = 0.0;
   ECA_FUNC_2 f3 = nullptr;
   ECA_FUNC_2 f4 = nullptr;
   ECA_FUNC_3 f5 = nullptr;
-  double f5arg;
+  double f5arg = 0.0;
   ECA_EPILOG epilog = ECA_NONE;
 };
 
@@ -156,7 +156,7 @@ struct ECA_MINOR_REQUEST_ELEMENT_2
   const char *longname = nullptr;
   const char *units = nullptr;
   ECA_FUNC_1 h1 = nullptr;
-  double h1arg;
+  double h1arg = 0.0;
   ECA_FUNC_2 h2 = nullptr;
 };
 
@@ -188,7 +188,7 @@ struct ECA_REQUEST_3
   const char *name = nullptr;
   const char *longname = nullptr;
   const char *units = nullptr;
-  int refdate;
+  int refdate = 0;
   ECA_FUNC_2 f1 = nullptr;
   ECA_FUNC_2 f2 = nullptr;
   ECA_FUNC_2 f3 = nullptr;
@@ -222,12 +222,12 @@ struct ECA_REQUEST_4
   const char *longname2 = nullptr;
   const char *units2 = nullptr;
   ECA_FUNC_1 s1 = nullptr;
-  double s1arg;
+  double s1arg = 0.0;
   ECA_FUNC_1 s2 = nullptr;
-  double s2arg;
+  double s2arg = 0.0;
   ECA_FUNC_1 s3 = nullptr;
-  double s3arg;
-  int consecutiveDays;
+  double s3arg = 0.0;
+  int consecutiveDays = 0;
 };
 
 /**
@@ -249,11 +249,11 @@ struct ETCCDI_REQUEST
   const char *name = nullptr;
   const char *longname = nullptr;
   const char *units = nullptr;
-  int pn;
-  int ndates;
-  int startboot;
-  int endboot;
-  int func2;
+  int pn = 0;
+  int ndates = 0;
+  int startboot = 0;
+  int endboot = 0;
+  int func2 = 0;
 };
 
 /**
