@@ -105,7 +105,7 @@ remap_bicubic_weights(RemapSearch &rsearch, RemapVars &rv)
   // Loop over destination grid
 
 #ifdef _OPENMP
-#pragma omp parallel for default(none) shared(atomicCount, rsearch, weightLinks, tgt_grid_size, src_grid, tgt_grid, rv)
+#pragma omp parallel for default(shared)
 #endif
   for (size_t tgt_cell_add = 0; tgt_cell_add < tgt_grid_size; ++tgt_cell_add)
     {
@@ -218,14 +218,14 @@ remap_bicubic(RemapSearch &rsearch, const Varray<T> &src_array, Varray<T> &tgt_a
   if (std::isnan(missval))
     {
 #ifdef _OPENMP
-#pragma omp parallel for default(none) schedule(static) shared(src_grid_size, src_array, src_grid_mask, missval)
+#pragma omp parallel for default(shared) schedule(static)
 #endif
       for (size_t i = 0; i < src_grid_size; ++i) src_grid_mask[i] = !DBL_IS_EQUAL(src_array[i], missval);
     }
   else
     {
 #ifdef _OPENMP
-#pragma omp parallel for default(none) schedule(static) shared(src_grid_size, src_array, src_grid_mask, missval)
+#pragma omp parallel for default(shared) schedule(static)
 #endif
       for (size_t i = 0; i < src_grid_size; ++i) src_grid_mask[i] = !IS_EQUAL(src_array[i], missval);
     }
@@ -240,8 +240,7 @@ remap_bicubic(RemapSearch &rsearch, const Varray<T> &src_array, Varray<T> &tgt_a
   // Loop over destination grid
 
 #ifdef _OPENMP
-#pragma omp parallel for default(none) \
-    shared(atomicCount, rsearch, tgt_grid_size, src_grid, tgt_grid, src_array, tgt_array, missval, src_grid_mask, gradients)
+#pragma omp parallel for default(shared)
 #endif
   for (size_t tgt_cell_add = 0; tgt_cell_add < tgt_grid_size; ++tgt_cell_add)
     {
